Plugins/WizardPlugins/PyRegExpWizard/PyRegExpWizardDialog.py

changeset 15
f6ccc31d6e72
parent 13
1af94a91f439
child 45
9a18f4dbb493
--- a/Plugins/WizardPlugins/PyRegExpWizard/PyRegExpWizardDialog.py	Sat Jan 02 16:15:57 2010 +0000
+++ b/Plugins/WizardPlugins/PyRegExpWizard/PyRegExpWizardDialog.py	Sat Jan 02 17:09:08 2010 +0000
@@ -32,7 +32,7 @@
         Constructor
         
         @param parent parent widget (QWidget)
-        @param fromEric flag indicating a call from within eric4
+        @param fromEric flag indicating a call from within eric5
         """
         QWidget.__init__(self,parent)
         self.setupUi(self)
@@ -358,7 +358,7 @@
         """
         Private slot to copy the regexp string into the clipboard.
         
         This slot is only available, if not called from within eric4.
         """
         escaped = self.regexpTextEdit.toPlainText()
         if escaped:
@@ -633,7 +633,7 @@
         Constructor
         
         @param parent parent widget (QWidget)
-        @param fromEric flag indicating a call from within eric4
+        @param fromEric flag indicating a call from within eric5
         """
         QDialog.__init__(self, parent)
         self.setModal(fromEric)
@@ -678,4 +678,4 @@
         self.resize(size)
         
         self.connect(self.cw.buttonBox, SIGNAL("accepted()"), self.close)
-        self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.close)
+        self.connect(self.cw.buttonBox, SIGNAL("rejected()"), self.close)
\ No newline at end of file
@@ -358,7 +358,7 @@
         Private slot to copy the regexp string into the clipboard.
         
-        This slot is only available, if not called from within eric4.
+        This slot is only available, if not called from within eric5.
         """
         escaped = self.regexpTextEdit.toPlainText()

eric ide

mercurial